@@ -45,7 +45,7 @@ for dep in info.get('depends', []):
 requires.append('trytond >= %s.%s, < %s.%s' %
     (major_version, minor_version, major_version, minor_version + 1))
 
-setup(name='health_who_essential_medicines',
+setup(name='trytond_health_who_essential_medicines',
     version=info.get('version', '0.0.1'),
     description=info.get('description', 'GNU Health Genetics Module'),
     author=info.get('author', 'GNU Solidario'),
